<template>
	<div class="pc-prompts">
		<div class="title flex items-center justify-between">
			<div class="flex item-center">
				<span>提问示例</span>
				<span class="split"></span>
				<span class="change cursor-pointer" @click="advanceExampleClick">高级示例 ></span>
			</div>
			<div class="cursor-pointer">
				<span class="mr-1 changeBatch">换一批</span>
				<i class="iconfont icon-shuaxin"></i>
			</div>
		</div>

		<div class="main">
			<div
				class="main_item flex items-center cursor-pointer"
				v-for="(item, index) in state.exampleContent"
				:key="item.ID"
				:class="{ main_item_active: item.ID === state.exampleIndex }"
				@click="changeExample(item)"
			>
				<div class="left flex items-center justify-center" :class="['color' + index]">
					<img :src="item.Icon" alt="" />
				</div>
				<div class="right">
					<h4>{{ item.Title }}</h4>
					<p>{{ item.Content }}</p>
				</div>
			</div>
		</div>
		<el-drawer v-model="state.isShowAdvanceExample" direction="rtl" size="30%">
			<div class="box-border w100 bg-[#e0e7fb] relative flex items-center justify-center" style="padding: 30px 20px 26px">
				<!-- <el-tabs v-model="state.activeName" type="card" @tab-click="handleClick" class="set-tabs">
					<el-tab-pane label="提问示例" name="questionExample">提问示例</el-tab-pane>
					<el-tab-pane label="指令模板" name="instructionTemplate">指令模板</el-tab-pane>
				</el-tabs> -->
				<div
					class="box-border flex w-[203px] h-[32px] rounded-md items-center justify-between cursor-pointer relative border border-solid border-[#2c2d33]"
				>
					<!-- <div class="w-[108px] h100 rounded-[5px] bg-transparent absolute left-0 transition-all"></div> -->

					<div
						class="tabbar-item"
						:class="state.activeName === item.ID ? 'set-tabbar-active' : ''"
						@click="handleTabClick(item)"
						v-for="item in state.tabNameList"
						:key="item.ID"
					>
						{{ item.Name }}
					</div>
				</div>
			</div>
		</el-drawer>
	</div>
</template>

<script setup lang="ts">
import { reactive } from 'vue';
let state = reactive({
	exampleContent: [
		{
			ID: 1,
			Icon: '/static/images/wave/ChatImg.png',
			Title: '解读李四的反应',
			Content: '张三打了李四一巴掌,李四对张三说:"你是不是没吃饭",李四说这句话含义是?',
		},
		{
			ID: 2,
			Icon: '/static/images/wave/ChatImg.png',
			Title: '解释努力与内卷的区别',
			Content: '怎么解释努力和内卷的区别?',
		},
		{
			ID: 3,
			Icon: '/static/images/wave/ChatImg.png',
			Title: '其他问题',
			Content: '请搜索你想知道的问题',
		},
		{
			ID: 4,
			Icon: '/static/images/wave/ChatImg.png',
			Title: '给宝宝取有文化内涵的名字',
			Content: '请以诗经中的典故给男宝宝取名，姓顾，名字要求3个字，给5个名字供我选择。',
		},
	],
	tabNameList: [
		{ ID: 1, Name: '提问示例' },
		{ ID: 2, Name: '指令模板' },
	],
	exampleIndex: 0,
	isShowAdvanceExample: false,
	activeName: 1,
});
const changeExample = (item) => {
	state.exampleIndex = item.ID;
};
//高级示例
const advanceExampleClick = () => {
	state.isShowAdvanceExample = true;
};
const handleTabClick = (item) => {
	console.log(item.ID);
	state.activeName = item.ID;
};
</script>
<style scoped lang="scss">
.pc-prompts {
	-webkit-box-sizing: border-box;
	box-sizing: border-box;
	margin-top: 40px;
	width: 760px;
	padding: 0;
	font-size: 14px;
	.title {
		color: #999;
		line-height: 14px;
		.split {
			height: 12px;
			width: 2px;
			background-color: #ccc;
			margin: 0 10px;
		}
		span {
			color: rgb(32, 33, 35);
			font-size: 14px;
		}
		.changeBatch {
			color: #999;
			font-size: 12px;
			transition: color 0.2s ease-in-out;
		}
		.change {
			color: #999;
			transition: color 0.2s ease-in-out;
		}
	}
	.main {
		width: calc(100% + 16px);
		display: flex;
		flex-wrap: wrap;
		margin: 4px -8px 0;
		&_item {
			box-sizing: border-box;
			width: calc(50% - 16px);
			margin: 8px;
			padding: 12px;
			border: 1px solid #d9dbde;
			border-radius: 5px;
			background-color: transparent;
			-webkit-transition: border-color 0.2s, background-color 0.2s;
			-o-transition: border-color 0.2s, background-color 0.2s;
			transition: border-color 0.2s, background-color 0.2s;

			.left {
				width: 50px;
				height: 50px;
				border-radius: 5px;
			}
			.color0 {
				background: linear-gradient(180deg, #f63c8b, #fd216c);
			}
			.color1 {
				background: linear-gradient(180deg, #0ebfe1, #0ab2d3);
			}
			.color2 {
				background: linear-gradient(180deg, #9647fe, #7b5be8);
			}
			.color3 {
				background: linear-gradient(180deg, #fb894c, #ff7958);
			}
			.right {
				flex: 1;
				min-width: 0;
				margin-left: 12px;
				h4 {
					color: #202123;
					font-size: 13px;
					font-weight: 500;
					height: 16px;
					transition: background-color 0.2s;
				}
				p {
					font-size: 12px;
					margin-top: 6px;
					height: 34px;
					line-height: 17px;
					color: #8d8e99;
					overflow: hidden;
					-o-text-overflow: ellipsis;
					text-overflow: ellipsis;
					-webkit-line-clamp: 2;
					-webkit-box-orient: vertical;
				}
			}
		}
		&_item_active {
			border: 1px solid #007aff;
			background-color: #ebeef3;
			.right {
				h4 {
					color: #007aff;
				}
			}
		}
	}
}
.tabbar-item {
	width: 108px;
	height: 30px;
	font-size: 13px;
	font-weight: 400;
	line-height: 30px;
	text-align: center;
	cursor: pointer;
	// position: absolute;
	-o-transition: color 0.2s;
	transition: color 0.2s;
	&:nth-child(3) {
		top: 0;
		left: 0;
	}
}
.tabbar-item-active {
	color: #fff;
}
.set-tabbar-active {
	left: 95px;
	color: #fff;
	background-color: #000;
}
</style>
